Test coverage report: auction.models.defaults

# auction.models.defaults: 27 total statements, 100.0% covered

Generated: Mon 2013-04-29 18:13 CST

Source file: /home/slam/workspace/django-auction/auction/models/defaults.py

Stats: 24 executed, 0 missed, 3 excluded, 4 ignored

1. `from django.db import models`
2. `from django.utils.translation import ugettext_lazy as _`
3. `from auction.models.bases import BaseAuction, BaseAuctionLot, BaseBidBasket, BaseBidItem`
4. ``
5. `class Auction(BaseAuction):`
6. `class Meta:`
7. `abstract = False`
8. `app_label = 'auction'`
9. `verbose_name = _('Auction')`
10. `verbose_name_plural = _('Auctions')`
11. ``
12. `class Lot(BaseAuctionLot):`
13. `class Meta:`
14. `abstract = False`
15. `app_label = 'auction'`
16. `verbose_name = _('Auction lot')`
17. `verbose_name_plural = _('Auction lots')`
18. ``
19. `class BidBasket(BaseBidBasket):`
20. `class Meta:`
21. `abstract = False`
22. `app_label = 'auction'`
23. `verbose_name = _('Bid basket')`
24. `verbose_name_plural = _('Bid baskets')`
25. ``
26. `class BidItem(BaseBidItem):`
27. `class Meta:`
28. `abstract = False`
29. `app_label = 'auction'`
30. `verbose_name = _('Bid item')`
31. `verbose_name_plural = _('Bid items')`